pub struct ApplicationModuleLock {
pub protocol: String,
pub application_id: String,
pub desired_composition_digest: String,
pub catalog_snapshot_digest: String,
pub trust_policy_digest: String,
pub resolver_version: String,
pub modules: Vec<LockedModule>,
pub capability_bindings: Vec<LockedCapabilityBinding>,
}Fields
protocol: Stringapplication_id: Stringdesired_composition_digest: Stringcatalog_snapshot_digest: Stringtrust_policy_digest: Stringresolver_version: Stringmodules: Vec<LockedModule>capability_bindings: Vec<LockedCapabilityBinding>Trait Implementations
Sourceimpl Clone for ApplicationModuleLock
impl Clone for ApplicationModuleLock
Sourcefn clone(&self) -> ApplicationModuleLock
fn clone(&self) -> ApplicationModuleLock
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ApplicationModuleLock
impl Debug for ApplicationModuleLock
Sourceimpl<'de> Deserialize<'de> for ApplicationModuleLock
impl<'de> Deserialize<'de> for ApplicationModuleLock
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ApplicationModuleLock
Sourceimpl JsonSchema for ApplicationModuleLock
impl JsonSchema for ApplicationModuleLock
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ApplicationModuleLock
impl PartialEq for ApplicationModuleLock
Sourceimpl Serialize for ApplicationModuleLock
impl Serialize for ApplicationModuleLock
impl StructuralPartialEq for ApplicationModuleLock