pub struct CargoLockCandidate {
pub protocol: String,
pub current_lock_digest: String,
pub candidate_lock_digest: String,
pub changed_packages: Vec<CargoPackageChange>,
pub command: Vec<String>,
}Fields
protocol: Stringcurrent_lock_digest: Stringcandidate_lock_digest: Stringchanged_packages: Vec<CargoPackageChange>command: Vec<String>Trait Implementations
Sourceimpl Clone for CargoLockCandidate
impl Clone for CargoLockCandidate
Sourcefn clone(&self) -> CargoLockCandidate
fn clone(&self) -> CargoLockCandidate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CargoLockCandidate
impl Debug for CargoLockCandidate
Sourceimpl<'de> Deserialize<'de> for CargoLockCandidate
impl<'de> Deserialize<'de> for CargoLockCandidate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CargoLockCandidate
Sourceimpl JsonSchema for CargoLockCandidate
impl JsonSchema for CargoLockCandidate
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CargoLockCandidate
impl PartialEq for CargoLockCandidate
Sourceimpl Serialize for CargoLockCandidate
impl Serialize for CargoLockCandidate
impl StructuralPartialEq for CargoLockCandidate