pub struct DesiredModuleSelection {
pub module_id: String,
pub version_requirement: String,
pub optional_requirements: Vec<String>,
pub exact_release_digest: Option<String>,
pub delivery_preference: Option<ManagedDeliveryKind>,
}Fields
module_id: Stringversion_requirement: Stringoptional_requirements: Vec<String>exact_release_digest: Option<String>delivery_preference: Option<ManagedDeliveryKind>Trait Implementations
Sourceimpl Clone for DesiredModuleSelection
impl Clone for DesiredModuleSelection
Sourcefn clone(&self) -> DesiredModuleSelection
fn clone(&self) -> DesiredModuleSelection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DesiredModuleSelection
impl Debug for DesiredModuleSelection
Sourceimpl<'de> Deserialize<'de> for DesiredModuleSelection
impl<'de> Deserialize<'de> for DesiredModuleSelection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DesiredModuleSelection
Sourceimpl JsonSchema for DesiredModuleSelection
impl JsonSchema for DesiredModuleSelection
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DesiredModuleSelection
impl PartialEq for DesiredModuleSelection
Sourceimpl Serialize for DesiredModuleSelection
impl Serialize for DesiredModuleSelection
impl StructuralPartialEq for DesiredModuleSelection