pub struct EndpointBinding {
pub binding_id: String,
pub service_ref: ServiceReference,
pub resolver_source: EndpointResolverSource,
pub allowed_bindings: Vec<ServiceTransportBinding>,
pub identity_policy: ServiceIdentityPolicy,
pub selection_policy: EndpointSelectionPolicy,
pub cache_policy: EndpointCachePolicy,
}Fields
binding_id: Stringservice_ref: ServiceReferenceresolver_source: EndpointResolverSourceallowed_bindings: Vec<ServiceTransportBinding>identity_policy: ServiceIdentityPolicyselection_policy: EndpointSelectionPolicycache_policy: EndpointCachePolicyTrait Implementations
Sourceimpl Clone for EndpointBinding
impl Clone for EndpointBinding
Sourcefn clone(&self) -> EndpointBinding
fn clone(&self) -> EndpointBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EndpointBinding
impl Debug for EndpointBinding
Sourceimpl<'de> Deserialize<'de> for EndpointBinding
impl<'de> Deserialize<'de> for EndpointBinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EndpointBinding
Sourceimpl JsonSchema for EndpointBinding
impl JsonSchema for EndpointBinding
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EndpointBinding
impl PartialEq for EndpointBinding
Sourceimpl Serialize for EndpointBinding
impl Serialize for EndpointBinding
impl StructuralPartialEq for EndpointBinding