pub struct EndpointCachePolicy {
pub maximum_age_seconds: u64,
pub stale_if_source_unavailable_seconds: Option<u64>,
}Fields
maximum_age_seconds: u64Trait Implementations
Sourceimpl Clone for EndpointCachePolicy
impl Clone for EndpointCachePolicy
Sourcefn clone(&self) -> EndpointCachePolicy
fn clone(&self) -> EndpointCachePolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EndpointCachePolicy
impl Debug for EndpointCachePolicy
Sourceimpl<'de> Deserialize<'de> for EndpointCachePolicy
impl<'de> Deserialize<'de> for EndpointCachePolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EndpointCachePolicy
Sourceimpl JsonSchema for EndpointCachePolicy
impl JsonSchema for EndpointCachePolicy
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EndpointCachePolicy
impl PartialEq for EndpointCachePolicy
Sourceimpl Serialize for EndpointCachePolicy
impl Serialize for EndpointCachePolicy
impl StructuralPartialEq for EndpointCachePolicy