pub struct EndpointSelectionPolicy {
pub preferred_regions: Vec<String>,
pub require_distinct_failure_domains: bool,
}Fields
preferred_regions: Vec<String>require_distinct_failure_domains: boolTrait Implementations
Sourceimpl Clone for EndpointSelectionPolicy
impl Clone for EndpointSelectionPolicy
Sourcefn clone(&self) -> EndpointSelectionPolicy
fn clone(&self) -> EndpointSelectionPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EndpointSelectionPolicy
impl Debug for EndpointSelectionPolicy
Sourceimpl Default for EndpointSelectionPolicy
impl Default for EndpointSelectionPolicy
Sourcefn default() -> EndpointSelectionPolicy
fn default() -> EndpointSelectionPolicy
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EndpointSelectionPolicy
impl<'de> Deserialize<'de> for EndpointSelectionPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EndpointSelectionPolicy
Sourceimpl JsonSchema for EndpointSelectionPolicy
impl JsonSchema for EndpointSelectionPolicy
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EndpointSelectionPolicy
impl PartialEq for EndpointSelectionPolicy
Sourceimpl Serialize for EndpointSelectionPolicy
impl Serialize for EndpointSelectionPolicy
impl StructuralPartialEq for EndpointSelectionPolicy