pub struct InstalledServiceExport {
pub export_key: String,
pub module_id: String,
pub module_version: String,
pub module_release_digest: String,
pub manifest_digest: String,
pub contract_digests: Vec<String>,
}Fields
export_key: Stringmodule_id: Stringmodule_version: Stringmodule_release_digest: Stringmanifest_digest: Stringcontract_digests: Vec<String>Trait Implementations
Sourceimpl Clone for InstalledServiceExport
impl Clone for InstalledServiceExport
Sourcefn clone(&self) -> InstalledServiceExport
fn clone(&self) -> InstalledServiceExport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstalledServiceExport
impl Debug for InstalledServiceExport
Sourceimpl<'de> Deserialize<'de> for InstalledServiceExport
impl<'de> Deserialize<'de> for InstalledServiceExport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for InstalledServiceExport
Sourceimpl JsonSchema for InstalledServiceExport
impl JsonSchema for InstalledServiceExport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InstalledServiceExport
impl PartialEq for InstalledServiceExport
Sourceimpl Serialize for InstalledServiceExport
impl Serialize for InstalledServiceExport
impl StructuralPartialEq for InstalledServiceExport