pub struct LinkedCompositionSeam {
pub protocol: String,
pub host_manifest_path: String,
pub host_source_path: String,
pub generated_crate_path: String,
pub dependency_name: String,
pub lenso_version: String,
}Fields
protocol: Stringhost_manifest_path: Stringhost_source_path: Stringgenerated_crate_path: Stringdependency_name: Stringlenso_version: StringTrait Implementations
Sourceimpl Clone for LinkedCompositionSeam
impl Clone for LinkedCompositionSeam
Sourcefn clone(&self) -> LinkedCompositionSeam
fn clone(&self) -> LinkedCompositionSeam
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LinkedCompositionSeam
impl Debug for LinkedCompositionSeam
Sourceimpl<'de> Deserialize<'de> for LinkedCompositionSeam
impl<'de> Deserialize<'de> for LinkedCompositionSeam
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LinkedCompositionSeam
Sourceimpl JsonSchema for LinkedCompositionSeam
impl JsonSchema for LinkedCompositionSeam
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LinkedCompositionSeam
impl PartialEq for LinkedCompositionSeam
Sourceimpl Serialize for LinkedCompositionSeam
impl Serialize for LinkedCompositionSeam
impl StructuralPartialEq for LinkedCompositionSeam