pub struct LocalModuleOverride {
pub module_id: String,
pub path: String,
pub content_digest: String,
pub acknowledged_unverified: bool,
}Fields
module_id: Stringpath: Stringcontent_digest: Stringacknowledged_unverified: boolTrait Implementations
Sourceimpl Clone for LocalModuleOverride
impl Clone for LocalModuleOverride
Sourcefn clone(&self) -> LocalModuleOverride
fn clone(&self) -> LocalModuleOverride
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LocalModuleOverride
impl Debug for LocalModuleOverride
Sourceimpl<'de> Deserialize<'de> for LocalModuleOverride
impl<'de> Deserialize<'de> for LocalModuleOverride
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LocalModuleOverride
Sourceimpl JsonSchema for LocalModuleOverride
impl JsonSchema for LocalModuleOverride
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LocalModuleOverride
impl PartialEq for LocalModuleOverride
Sourceimpl Serialize for LocalModuleOverride
impl Serialize for LocalModuleOverride
impl StructuralPartialEq for LocalModuleOverride