pub struct LockedModule {Show 14 fields
pub module_id: String,
pub version: String,
pub release_digest: String,
pub manifest_digest: String,
pub delivery: ModuleDelivery,
pub reason: LockedModuleReason,
pub dependency_module_ids: Vec<String>,
pub crate_features: Vec<String>,
pub migration_artifacts: Vec<ArtifactReference>,
pub console_ui_artifact: Option<LockedConsoleUiArtifact>,
pub verification: VerificationEvaluation,
pub verification_cell: ModuleVerificationCell,
pub lifecycle: ModuleLifecycleState,
pub local_override_digest: Option<String>,
}Fields
module_id: Stringversion: Stringrelease_digest: Stringmanifest_digest: Stringdelivery: ModuleDeliveryreason: LockedModuleReasondependency_module_ids: Vec<String>crate_features: Vec<String>migration_artifacts: Vec<ArtifactReference>console_ui_artifact: Option<LockedConsoleUiArtifact>verification: VerificationEvaluationverification_cell: ModuleVerificationCelllifecycle: ModuleLifecycleStatelocal_override_digest: Option<String>Trait Implementations
Sourceimpl Clone for LockedModule
impl Clone for LockedModule
Sourcefn clone(&self) -> LockedModule
fn clone(&self) -> LockedModule
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LockedModule
impl Debug for LockedModule
Sourceimpl<'de> Deserialize<'de> for LockedModule
impl<'de> Deserialize<'de> for LockedModule
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LockedModule
Sourceimpl JsonSchema for LockedModule
impl JsonSchema for LockedModule
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LockedModule
impl PartialEq for LockedModule
Sourceimpl Serialize for LockedModule
impl Serialize for LockedModule
impl StructuralPartialEq for LockedModule