pub struct ModuleApproval {Show 14 fields
pub protocol: String,
pub approval_id: String,
pub plan_digest: String,
pub application_id: String,
pub environment_id: String,
pub expected_target_revision: u64,
pub boundary_id: String,
pub risk_class: ModuleRiskClass,
pub actor_id: String,
pub verified_authorities: Vec<String>,
pub reason: String,
pub issued_at: DateTime<Utc>,
pub expires_at: DateTime<Utc>,
pub nonce: String,
}Fields
protocol: Stringapproval_id: Stringplan_digest: Stringapplication_id: Stringenvironment_id: Stringexpected_target_revision: u64boundary_id: Stringrisk_class: ModuleRiskClassactor_id: Stringreason: Stringissued_at: DateTime<Utc>expires_at: DateTime<Utc>nonce: StringTrait Implementations
Sourceimpl Clone for ModuleApproval
impl Clone for ModuleApproval
Sourcefn clone(&self) -> ModuleApproval
fn clone(&self) -> ModuleApproval
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleApproval
impl Debug for ModuleApproval
Sourceimpl<'de> Deserialize<'de> for ModuleApproval
impl<'de> Deserialize<'de> for ModuleApproval
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleApproval
Sourceimpl JsonSchema for ModuleApproval
impl JsonSchema for ModuleApproval
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleApproval
impl PartialEq for ModuleApproval
Sourceimpl Serialize for ModuleApproval
impl Serialize for ModuleApproval
impl StructuralPartialEq for ModuleApproval