pub struct ModuleChangePlan {Show 24 fields
pub protocol: String,
pub plan_id: String,
pub plan_digest: String,
pub application_id: String,
pub environment_id: String,
pub expected_target_revision: u64,
pub request: ModuleRootChange,
pub current_desired_digest: String,
pub target_desired: DesiredModuleComposition,
pub target_desired_digest: String,
pub current_lock_digest: Option<String>,
pub target_lock: ApplicationModuleLock,
pub target_lock_digest: String,
pub catalog_snapshot_digest: String,
pub resolver_version: String,
pub trust_policy_digest: String,
pub compatibility_evidence_digest: String,
pub cargo_lock_candidate: Option<CargoLockCandidate>,
pub read_set: Vec<ModulePathPrecondition>,
pub effects: Vec<ModulePlanEffect>,
pub approval_boundaries: Vec<ModuleApprovalBoundary>,
pub validation_commands: Vec<String>,
pub next_actions: Vec<String>,
pub created_at: DateTime<Utc>,
}Fields
protocol: Stringplan_id: Stringplan_digest: Stringapplication_id: Stringenvironment_id: Stringexpected_target_revision: u64request: ModuleRootChangecurrent_desired_digest: Stringtarget_desired: DesiredModuleCompositiontarget_desired_digest: Stringcurrent_lock_digest: Option<String>target_lock: ApplicationModuleLocktarget_lock_digest: Stringcatalog_snapshot_digest: Stringresolver_version: Stringtrust_policy_digest: Stringcompatibility_evidence_digest: Stringcargo_lock_candidate: Option<CargoLockCandidate>read_set: Vec<ModulePathPrecondition>effects: Vec<ModulePlanEffect>approval_boundaries: Vec<ModuleApprovalBoundary>validation_commands: Vec<String>next_actions: Vec<String>created_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for ModuleChangePlan
impl Clone for ModuleChangePlan
Sourcefn clone(&self) -> ModuleChangePlan
fn clone(&self) -> ModuleChangePlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleChangePlan
impl Debug for ModuleChangePlan
Sourceimpl<'de> Deserialize<'de> for ModuleChangePlan
impl<'de> Deserialize<'de> for ModuleChangePlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleChangePlan
Sourceimpl JsonSchema for ModuleChangePlan
impl JsonSchema for ModuleChangePlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleChangePlan
impl PartialEq for ModuleChangePlan
Sourceimpl Serialize for ModuleChangePlan
impl Serialize for ModuleChangePlan
impl StructuralPartialEq for ModuleChangePlan