pub struct ModuleEnvironmentPolicy {
pub protocol: String,
pub policy_id: String,
pub revision: String,
pub mode: EnvironmentManagementMode,
pub require_distinct_approver: bool,
pub maximum_approval_age_seconds: u64,
pub maximum_lease_seconds: u64,
pub require_backup_for_non_local_destructive_effects: bool,
}Fields
protocol: Stringpolicy_id: Stringrevision: Stringmode: EnvironmentManagementModerequire_distinct_approver: boolmaximum_approval_age_seconds: u64maximum_lease_seconds: u64require_backup_for_non_local_destructive_effects: boolTrait Implementations
Sourceimpl Clone for ModuleEnvironmentPolicy
impl Clone for ModuleEnvironmentPolicy
Sourcefn clone(&self) -> ModuleEnvironmentPolicy
fn clone(&self) -> ModuleEnvironmentPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleEnvironmentPolicy
impl Debug for ModuleEnvironmentPolicy
Sourceimpl<'de> Deserialize<'de> for ModuleEnvironmentPolicy
impl<'de> Deserialize<'de> for ModuleEnvironmentPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleEnvironmentPolicy
Sourceimpl JsonSchema for ModuleEnvironmentPolicy
impl JsonSchema for ModuleEnvironmentPolicy
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleEnvironmentPolicy
impl PartialEq for ModuleEnvironmentPolicy
Sourceimpl Serialize for ModuleEnvironmentPolicy
impl Serialize for ModuleEnvironmentPolicy
impl StructuralPartialEq for ModuleEnvironmentPolicy