pub struct ModuleManagementSnapshot {
pub protocol: String,
pub status: ModuleManagementSnapshotStatus,
pub application_id: Option<String>,
pub desired: Option<DesiredModuleComposition>,
pub desired_digest: Option<String>,
pub application_lock: Option<ApplicationModuleLock>,
pub application_lock_digest: Option<String>,
pub planning_available: bool,
pub planning_context_digest: Option<String>,
pub execution_available: bool,
pub environment_policy: Option<ModuleEnvironmentPolicy>,
pub issues: Vec<String>,
}Fields
protocol: Stringstatus: ModuleManagementSnapshotStatusapplication_id: Option<String>desired: Option<DesiredModuleComposition>desired_digest: Option<String>application_lock: Option<ApplicationModuleLock>application_lock_digest: Option<String>planning_available: boolplanning_context_digest: Option<String>execution_available: boolenvironment_policy: Option<ModuleEnvironmentPolicy>issues: Vec<String>Trait Implementations
Sourceimpl Clone for ModuleManagementSnapshot
impl Clone for ModuleManagementSnapshot
Sourcefn clone(&self) -> ModuleManagementSnapshot
fn clone(&self) -> ModuleManagementSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleManagementSnapshot
impl Debug for ModuleManagementSnapshot
Sourceimpl<'de> Deserialize<'de> for ModuleManagementSnapshot
impl<'de> Deserialize<'de> for ModuleManagementSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleManagementSnapshot
Sourceimpl JsonSchema for ModuleManagementSnapshot
impl JsonSchema for ModuleManagementSnapshot
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleManagementSnapshot
impl PartialEq for ModuleManagementSnapshot
Sourceimpl Serialize for ModuleManagementSnapshot
impl Serialize for ModuleManagementSnapshot
impl StructuralPartialEq for ModuleManagementSnapshot