pub struct ModuleOperationJournal {
pub protocol: String,
pub operation_id: String,
pub events: Vec<ModuleOperationJournalEvent>,
}Fields
protocol: Stringoperation_id: Stringevents: Vec<ModuleOperationJournalEvent>Trait Implementations
Sourceimpl Clone for ModuleOperationJournal
impl Clone for ModuleOperationJournal
Sourcefn clone(&self) -> ModuleOperationJournal
fn clone(&self) -> ModuleOperationJournal
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleOperationJournal
impl Debug for ModuleOperationJournal
Sourceimpl<'de> Deserialize<'de> for ModuleOperationJournal
impl<'de> Deserialize<'de> for ModuleOperationJournal
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleOperationJournal
Sourceimpl JsonSchema for ModuleOperationJournal
impl JsonSchema for ModuleOperationJournal
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleOperationJournal
impl PartialEq for ModuleOperationJournal
Sourceimpl Serialize for ModuleOperationJournal
impl Serialize for ModuleOperationJournal
impl StructuralPartialEq for ModuleOperationJournal