pub struct ModuleOperationJournalEvent {Show 14 fields
pub protocol: String,
pub event_id: String,
pub operation_id: String,
pub attempt: u32,
pub revision: u64,
pub prior_event_digest: Option<String>,
pub plan_digest: String,
pub actor_id: String,
pub fencing_token: u64,
pub transition: ModuleOperationTransition,
pub outcome_code: String,
pub evidence_references: Vec<ArtifactReference>,
pub operation_after: ModuleOperation,
pub recorded_at: DateTime<Utc>,
}Fields
protocol: Stringevent_id: Stringoperation_id: Stringattempt: u32revision: u64prior_event_digest: Option<String>plan_digest: Stringactor_id: Stringfencing_token: u64transition: ModuleOperationTransitionoutcome_code: Stringevidence_references: Vec<ArtifactReference>operation_after: ModuleOperationrecorded_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for ModuleOperationJournalEvent
impl Clone for ModuleOperationJournalEvent
Sourcefn clone(&self) -> ModuleOperationJournalEvent
fn clone(&self) -> ModuleOperationJournalEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleOperationJournalEvent
impl Debug for ModuleOperationJournalEvent
Sourceimpl<'de> Deserialize<'de> for ModuleOperationJournalEvent
impl<'de> Deserialize<'de> for ModuleOperationJournalEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleOperationJournalEvent
Sourceimpl JsonSchema for ModuleOperationJournalEvent
impl JsonSchema for ModuleOperationJournalEvent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ModuleOperationJournalEvent