pub struct ModuleOperationLease {
pub application_id: String,
pub holder_id: String,
pub fencing_token: u64,
pub revision: u64,
pub acquired_at: DateTime<Utc>,
pub expires_at: DateTime<Utc>,
}Fields
application_id: Stringholder_id: Stringfencing_token: u64revision: u64acquired_at: DateTime<Utc>expires_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for ModuleOperationLease
impl Clone for ModuleOperationLease
Sourcefn clone(&self) -> ModuleOperationLease
fn clone(&self) -> ModuleOperationLease
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleOperationLease
impl Debug for ModuleOperationLease
Sourceimpl<'de> Deserialize<'de> for ModuleOperationLease
impl<'de> Deserialize<'de> for ModuleOperationLease
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleOperationLease
Sourceimpl JsonSchema for ModuleOperationLease
impl JsonSchema for ModuleOperationLease
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleOperationLease
impl PartialEq for ModuleOperationLease
Sourceimpl Serialize for ModuleOperationLease
impl Serialize for ModuleOperationLease
impl StructuralPartialEq for ModuleOperationLease