pub struct ModulePlanningContext {
pub protocol: String,
pub system_id: String,
pub application_id: String,
pub environment_id: String,
pub expected_target_revision: u64,
pub catalog_snapshot_digest: String,
pub trust_policy_digest: String,
pub compatibility_evidence_digest: String,
pub resolver_version: String,
pub candidates: Vec<ModuleResolutionCandidate>,
pub service_deployments: Vec<ServiceDeploymentBinding>,
pub cargo_offline: bool,
}Fields
protocol: Stringsystem_id: Stringapplication_id: Stringenvironment_id: Stringexpected_target_revision: u64catalog_snapshot_digest: Stringtrust_policy_digest: Stringcompatibility_evidence_digest: Stringresolver_version: Stringcandidates: Vec<ModuleResolutionCandidate>service_deployments: Vec<ServiceDeploymentBinding>cargo_offline: boolTrait Implementations
Sourceimpl Clone for ModulePlanningContext
impl Clone for ModulePlanningContext
Sourcefn clone(&self) -> ModulePlanningContext
fn clone(&self) -> ModulePlanningContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModulePlanningContext
impl Debug for ModulePlanningContext
Sourceimpl<'de> Deserialize<'de> for ModulePlanningContext
impl<'de> Deserialize<'de> for ModulePlanningContext
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModulePlanningContext
Sourceimpl JsonSchema for ModulePlanningContext
impl JsonSchema for ModulePlanningContext
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModulePlanningContext
impl PartialEq for ModulePlanningContext
Sourceimpl Serialize for ModulePlanningContext
impl Serialize for ModulePlanningContext
impl StructuralPartialEq for ModulePlanningContext