pub struct ModuleRepairPlan {
pub protocol: String,
pub repair_plan_id: String,
pub repair_plan_digest: String,
pub original_operation_id: String,
pub original_operation_revision: u64,
pub application_id: String,
pub environment_id: String,
pub observed_state_digest: String,
pub completed_effect_ids: Vec<String>,
pub actions: Vec<ModuleRepairAction>,
pub approval_boundaries: Vec<ModuleApprovalBoundary>,
pub created_at: DateTime<Utc>,
}Fields
protocol: Stringrepair_plan_id: Stringrepair_plan_digest: Stringoriginal_operation_id: Stringoriginal_operation_revision: u64application_id: Stringenvironment_id: Stringobserved_state_digest: Stringcompleted_effect_ids: Vec<String>actions: Vec<ModuleRepairAction>approval_boundaries: Vec<ModuleApprovalBoundary>created_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for ModuleRepairPlan
impl Clone for ModuleRepairPlan
Sourcefn clone(&self) -> ModuleRepairPlan
fn clone(&self) -> ModuleRepairPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleRepairPlan
impl Debug for ModuleRepairPlan
Sourceimpl<'de> Deserialize<'de> for ModuleRepairPlan
impl<'de> Deserialize<'de> for ModuleRepairPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleRepairPlan
Sourceimpl JsonSchema for ModuleRepairPlan
impl JsonSchema for ModuleRepairPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleRepairPlan
impl PartialEq for ModuleRepairPlan
Sourceimpl Serialize for ModuleRepairPlan
impl Serialize for ModuleRepairPlan
impl StructuralPartialEq for ModuleRepairPlan