pub struct ModuleResolutionCandidate {
pub catalog_snapshot_digest: String,
pub release_digest: String,
pub release: ModuleRelease,
pub eligibility: ModuleEligibility,
pub verification_cell: ModuleVerificationCell,
}Fields
catalog_snapshot_digest: Stringrelease_digest: Stringrelease: ModuleReleaseeligibility: ModuleEligibilityverification_cell: ModuleVerificationCellTrait Implementations
Sourceimpl Clone for ModuleResolutionCandidate
impl Clone for ModuleResolutionCandidate
Sourcefn clone(&self) -> ModuleResolutionCandidate
fn clone(&self) -> ModuleResolutionCandidate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleResolutionCandidate
impl Debug for ModuleResolutionCandidate
Sourceimpl<'de> Deserialize<'de> for ModuleResolutionCandidate
impl<'de> Deserialize<'de> for ModuleResolutionCandidate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleResolutionCandidate
Sourceimpl JsonSchema for ModuleResolutionCandidate
impl JsonSchema for ModuleResolutionCandidate
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ModuleResolutionCandidate