pub struct ModuleResolutionConflict {
pub protocol: String,
pub code: String,
pub module_id: Option<String>,
pub dependency_paths: Vec<Vec<String>>,
pub constraints: Vec<String>,
pub eligible_alternatives: Vec<String>,
}Fields
protocol: Stringcode: Stringmodule_id: Option<String>dependency_paths: Vec<Vec<String>>constraints: Vec<String>eligible_alternatives: Vec<String>Trait Implementations
Sourceimpl Clone for ModuleResolutionConflict
impl Clone for ModuleResolutionConflict
Sourcefn clone(&self) -> ModuleResolutionConflict
fn clone(&self) -> ModuleResolutionConflict
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleResolutionConflict
impl Debug for ModuleResolutionConflict
Sourceimpl<'de> Deserialize<'de> for ModuleResolutionConflict
impl<'de> Deserialize<'de> for ModuleResolutionConflict
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleResolutionConflict
Sourceimpl JsonSchema for ModuleResolutionConflict
impl JsonSchema for ModuleResolutionConflict
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleResolutionConflict
impl PartialEq for ModuleResolutionConflict
Sourceimpl Serialize for ModuleResolutionConflict
impl Serialize for ModuleResolutionConflict
impl StructuralPartialEq for ModuleResolutionConflict