pub struct ModuleWorkspaceBackup {
pub path: String,
pub existence: PathExistence,
pub file_type: ManagedFileType,
pub content_base64: Option<String>,
pub content_digest: Option<String>,
pub mode: Option<u32>,
}Fields
path: Stringexistence: PathExistencefile_type: ManagedFileTypecontent_base64: Option<String>content_digest: Option<String>mode: Option<u32>Trait Implementations
Sourceimpl Clone for ModuleWorkspaceBackup
impl Clone for ModuleWorkspaceBackup
Sourcefn clone(&self) -> ModuleWorkspaceBackup
fn clone(&self) -> ModuleWorkspaceBackup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleWorkspaceBackup
impl Debug for ModuleWorkspaceBackup
Sourceimpl<'de> Deserialize<'de> for ModuleWorkspaceBackup
impl<'de> Deserialize<'de> for ModuleWorkspaceBackup
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleWorkspaceBackup
Sourceimpl JsonSchema for ModuleWorkspaceBackup
impl JsonSchema for ModuleWorkspaceBackup
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleWorkspaceBackup
impl PartialEq for ModuleWorkspaceBackup
Sourceimpl Serialize for ModuleWorkspaceBackup
impl Serialize for ModuleWorkspaceBackup
impl StructuralPartialEq for ModuleWorkspaceBackup