pub struct ProviderRuntimeModule {
pub export_key: String,
pub module_id: String,
pub module_version: String,
pub module_release_digest: String,
pub manifest_digest: String,
pub contract_digests: Vec<String>,
pub manifest: ModuleManifest,
}Fields
export_key: Stringmodule_id: Stringmodule_version: Stringmodule_release_digest: Stringmanifest_digest: Stringcontract_digests: Vec<String>manifest: ModuleManifestTrait Implementations
Sourceimpl Clone for ProviderRuntimeModule
impl Clone for ProviderRuntimeModule
Sourcefn clone(&self) -> ProviderRuntimeModule
fn clone(&self) -> ProviderRuntimeModule
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderRuntimeModule
impl Debug for ProviderRuntimeModule
Sourceimpl<'de> Deserialize<'de> for ProviderRuntimeModule
impl<'de> Deserialize<'de> for ProviderRuntimeModule
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProviderRuntimeModule
Sourceimpl JsonSchema for ProviderRuntimeModule
impl JsonSchema for ProviderRuntimeModule
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProviderRuntimeModule
impl PartialEq for ProviderRuntimeModule
Sourceimpl Serialize for ProviderRuntimeModule
impl Serialize for ProviderRuntimeModule
impl StructuralPartialEq for ProviderRuntimeModule