pub struct ProviderRuntimePlan {
pub protocol: String,
pub system_id: String,
pub application_id: String,
pub environment_id: String,
pub application_lock_digest: String,
pub service_installation_revision: u64,
pub providers: Vec<ProviderRuntimeService>,
}Fields
protocol: Stringsystem_id: Stringapplication_id: Stringenvironment_id: Stringapplication_lock_digest: Stringservice_installation_revision: u64providers: Vec<ProviderRuntimeService>Trait Implementations
Sourceimpl Clone for ProviderRuntimePlan
impl Clone for ProviderRuntimePlan
Sourcefn clone(&self) -> ProviderRuntimePlan
fn clone(&self) -> ProviderRuntimePlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderRuntimePlan
impl Debug for ProviderRuntimePlan
Sourceimpl<'de> Deserialize<'de> for ProviderRuntimePlan
impl<'de> Deserialize<'de> for ProviderRuntimePlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProviderRuntimePlan
Sourceimpl JsonSchema for ProviderRuntimePlan
impl JsonSchema for ProviderRuntimePlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProviderRuntimePlan
impl PartialEq for ProviderRuntimePlan
Sourceimpl Serialize for ProviderRuntimePlan
impl Serialize for ProviderRuntimePlan
impl StructuralPartialEq for ProviderRuntimePlan