pub struct ProviderRuntimePlanIssue {
pub code: ProviderRuntimePlanIssueCode,
pub path: String,
pub message: String,
pub next_action: String,
}Fields
code: ProviderRuntimePlanIssueCodepath: Stringmessage: Stringnext_action: StringTrait Implementations
Sourceimpl Clone for ProviderRuntimePlanIssue
impl Clone for ProviderRuntimePlanIssue
Sourcefn clone(&self) -> ProviderRuntimePlanIssue
fn clone(&self) -> ProviderRuntimePlanIssue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderRuntimePlanIssue
impl Debug for ProviderRuntimePlanIssue
Sourceimpl<'de> Deserialize<'de> for ProviderRuntimePlanIssue
impl<'de> Deserialize<'de> for ProviderRuntimePlanIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProviderRuntimePlanIssue
Sourceimpl JsonSchema for ProviderRuntimePlanIssue
impl JsonSchema for ProviderRuntimePlanIssue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProviderRuntimePlanIssue
impl PartialEq for ProviderRuntimePlanIssue
Sourceimpl Serialize for ProviderRuntimePlanIssue
impl Serialize for ProviderRuntimePlanIssue
impl StructuralPartialEq for ProviderRuntimePlanIssue