pub struct ProviderRuntimeService {
pub service_ref: ServiceReference,
pub service_release: InstalledServiceRelease,
pub endpoint_binding: EndpointBinding,
pub modules: Vec<ProviderRuntimeModule>,
}Fields
service_ref: ServiceReferenceservice_release: InstalledServiceReleaseendpoint_binding: EndpointBindingmodules: Vec<ProviderRuntimeModule>Trait Implementations
Sourceimpl Clone for ProviderRuntimeService
impl Clone for ProviderRuntimeService
Sourcefn clone(&self) -> ProviderRuntimeService
fn clone(&self) -> ProviderRuntimeService
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderRuntimeService
impl Debug for ProviderRuntimeService
Sourceimpl<'de> Deserialize<'de> for ProviderRuntimeService
impl<'de> Deserialize<'de> for ProviderRuntimeService
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProviderRuntimeService
Sourceimpl JsonSchema for ProviderRuntimeService
impl JsonSchema for ProviderRuntimeService
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProviderRuntimeService
impl PartialEq for ProviderRuntimeService
Sourceimpl Serialize for ProviderRuntimeService
impl Serialize for ProviderRuntimeService
impl StructuralPartialEq for ProviderRuntimeService