pub struct ServiceDeploymentBinding {
pub service_id: String,
pub service_release_digest: String,
pub adapter: ServiceDeploymentAdapterKind,
pub installation: Option<ServiceInstallation>,
pub install: Option<ServiceDeploymentAction>,
pub remove: Option<ServiceDeploymentAction>,
pub restart: Option<ServiceDeploymentAction>,
}Fields
service_id: Stringservice_release_digest: Stringadapter: ServiceDeploymentAdapterKindinstallation: Option<ServiceInstallation>install: Option<ServiceDeploymentAction>remove: Option<ServiceDeploymentAction>restart: Option<ServiceDeploymentAction>Trait Implementations
Sourceimpl Clone for ServiceDeploymentBinding
impl Clone for ServiceDeploymentBinding
Sourcefn clone(&self) -> ServiceDeploymentBinding
fn clone(&self) -> ServiceDeploymentBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServiceDeploymentBinding
impl Debug for ServiceDeploymentBinding
Sourceimpl<'de> Deserialize<'de> for ServiceDeploymentBinding
impl<'de> Deserialize<'de> for ServiceDeploymentBinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceDeploymentBinding
Sourceimpl JsonSchema for ServiceDeploymentBinding
impl JsonSchema for ServiceDeploymentBinding
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServiceDeploymentBinding
impl PartialEq for ServiceDeploymentBinding
Sourceimpl Serialize for ServiceDeploymentBinding
impl Serialize for ServiceDeploymentBinding
impl StructuralPartialEq for ServiceDeploymentBinding