pub struct ServiceIdentityPolicy {
pub principal: String,
pub audience: String,
pub trust_profile: String,
pub credential_references: Vec<String>,
}Fields
principal: Stringaudience: Stringtrust_profile: Stringcredential_references: Vec<String>Trait Implementations
Sourceimpl Clone for ServiceIdentityPolicy
impl Clone for ServiceIdentityPolicy
Sourcefn clone(&self) -> ServiceIdentityPolicy
fn clone(&self) -> ServiceIdentityPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServiceIdentityPolicy
impl Debug for ServiceIdentityPolicy
Sourceimpl<'de> Deserialize<'de> for ServiceIdentityPolicy
impl<'de> Deserialize<'de> for ServiceIdentityPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceIdentityPolicy
Sourceimpl JsonSchema for ServiceIdentityPolicy
impl JsonSchema for ServiceIdentityPolicy
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServiceIdentityPolicy
impl PartialEq for ServiceIdentityPolicy
Sourceimpl Serialize for ServiceIdentityPolicy
impl Serialize for ServiceIdentityPolicy
impl StructuralPartialEq for ServiceIdentityPolicy