pub struct ServiceInstallation {
pub service_ref: ServiceReference,
pub profile: ServiceResponsibilityProfile,
pub desired_mode: ServiceDesiredMode,
pub service_release: InstalledServiceRelease,
pub exports: Vec<InstalledServiceExport>,
pub config_bindings: Vec<ServiceConfigBinding>,
pub endpoint_binding: EndpointBinding,
pub lifecycle_binding: ServiceLifecycleBinding,
}Fields
service_ref: ServiceReferenceprofile: ServiceResponsibilityProfiledesired_mode: ServiceDesiredModeservice_release: InstalledServiceReleaseexports: Vec<InstalledServiceExport>config_bindings: Vec<ServiceConfigBinding>endpoint_binding: EndpointBindinglifecycle_binding: ServiceLifecycleBindingTrait Implementations
Sourceimpl Clone for ServiceInstallation
impl Clone for ServiceInstallation
Sourcefn clone(&self) -> ServiceInstallation
fn clone(&self) -> ServiceInstallation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServiceInstallation
impl Debug for ServiceInstallation
Sourceimpl<'de> Deserialize<'de> for ServiceInstallation
impl<'de> Deserialize<'de> for ServiceInstallation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceInstallation
Sourceimpl JsonSchema for ServiceInstallation
impl JsonSchema for ServiceInstallation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServiceInstallation
impl PartialEq for ServiceInstallation
Sourceimpl Serialize for ServiceInstallation
impl Serialize for ServiceInstallation
impl StructuralPartialEq for ServiceInstallation