pub struct ServiceInstallationPlan {Show 15 fields
pub protocol: String,
pub plan_id: String,
pub plan_digest: String,
pub system_id: String,
pub environment_id: String,
pub kind: ServiceInstallationPlanKind,
pub change: ServiceInstallationChange,
pub expected_revision: u64,
pub expected_state_digest: String,
pub target_revision: u64,
pub target_state_digest: String,
pub target: ServiceInstallationSet,
pub required_authority: String,
pub next_actions: Vec<String>,
pub created_at: DateTime<Utc>,
}Fields
protocol: Stringplan_id: Stringplan_digest: Stringsystem_id: Stringenvironment_id: Stringkind: ServiceInstallationPlanKindchange: ServiceInstallationChangeexpected_revision: u64expected_state_digest: Stringtarget_revision: u64target_state_digest: Stringtarget: ServiceInstallationSetnext_actions: Vec<String>created_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for ServiceInstallationPlan
impl Clone for ServiceInstallationPlan
Sourcefn clone(&self) -> ServiceInstallationPlan
fn clone(&self) -> ServiceInstallationPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServiceInstallationPlan
impl Debug for ServiceInstallationPlan
Sourceimpl<'de> Deserialize<'de> for ServiceInstallationPlan
impl<'de> Deserialize<'de> for ServiceInstallationPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceInstallationPlan
Sourceimpl JsonSchema for ServiceInstallationPlan
impl JsonSchema for ServiceInstallationPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServiceInstallationPlan
impl PartialEq for ServiceInstallationPlan
Sourceimpl Serialize for ServiceInstallationPlan
impl Serialize for ServiceInstallationPlan
impl StructuralPartialEq for ServiceInstallationPlan