pub struct ServiceInstallationReceipt {Show 18 fields
pub protocol: String,
pub receipt_id: String,
pub operation_id: String,
pub plan_id: String,
pub plan_digest: String,
pub actor_id: String,
pub verified_authorities: Vec<String>,
pub system_id: String,
pub environment_id: String,
pub service_ref: ServiceReference,
pub prior_revision: u64,
pub target_revision: u64,
pub prior_state_digest: String,
pub target_state_digest: String,
pub outcome: ServiceInstallationOutcome,
pub reasons: Vec<String>,
pub next_actions: Vec<String>,
pub committed_at: DateTime<Utc>,
}Fields
protocol: Stringreceipt_id: Stringoperation_id: Stringplan_id: Stringplan_digest: Stringactor_id: Stringsystem_id: Stringenvironment_id: Stringservice_ref: ServiceReferenceprior_revision: u64target_revision: u64prior_state_digest: Stringtarget_state_digest: Stringoutcome: ServiceInstallationOutcomereasons: Vec<String>next_actions: Vec<String>committed_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for ServiceInstallationReceipt
impl Clone for ServiceInstallationReceipt
Sourcefn clone(&self) -> ServiceInstallationReceipt
fn clone(&self) -> ServiceInstallationReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServiceInstallationReceipt
impl Debug for ServiceInstallationReceipt
Sourceimpl<'de> Deserialize<'de> for ServiceInstallationReceipt
impl<'de> Deserialize<'de> for ServiceInstallationReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceInstallationReceipt
Sourceimpl JsonSchema for ServiceInstallationReceipt
impl JsonSchema for ServiceInstallationReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ServiceInstallationReceipt