pub struct ServiceReference {
pub system_id: String,
pub service_id: String,
}Fields
system_id: Stringservice_id: StringTrait Implementations
Sourceimpl Clone for ServiceReference
impl Clone for ServiceReference
Sourcefn clone(&self) -> ServiceReference
fn clone(&self) -> ServiceReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServiceReference
impl Debug for ServiceReference
Sourceimpl<'de> Deserialize<'de> for ServiceReference
impl<'de> Deserialize<'de> for ServiceReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceReference
Sourceimpl JsonSchema for ServiceReference
impl JsonSchema for ServiceReference
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ServiceReference
impl Ord for ServiceReference
Sourcefn cmp(&self, other: &ServiceReference) -> Ordering
fn cmp(&self, other: &ServiceReference) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ServiceReference
impl PartialEq for ServiceReference
Sourceimpl PartialOrd for ServiceReference
impl PartialOrd for ServiceReference
Sourceimpl Serialize for ServiceReference
impl Serialize for ServiceReference
impl StructuralPartialEq for ServiceReference