pub struct StaticEndpointDeclaration {
pub address: String,
pub binding: ServiceTransportBinding,
pub region: Option<String>,
pub failure_domain: Option<String>,
pub priority: u32,
pub weight: u32,
}Fields
address: Stringbinding: ServiceTransportBindingregion: Option<String>failure_domain: Option<String>priority: u32weight: u32Trait Implementations
Sourceimpl Clone for StaticEndpointDeclaration
impl Clone for StaticEndpointDeclaration
Sourcefn clone(&self) -> StaticEndpointDeclaration
fn clone(&self) -> StaticEndpointDeclaration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StaticEndpointDeclaration
impl Debug for StaticEndpointDeclaration
Sourceimpl<'de> Deserialize<'de> for StaticEndpointDeclaration
impl<'de> Deserialize<'de> for StaticEndpointDeclaration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for StaticEndpointDeclaration
Sourceimpl JsonSchema for StaticEndpointDeclaration
impl JsonSchema for StaticEndpointDeclaration
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for StaticEndpointDeclaration