pub struct WorkspaceModuleManagement { /* private fields */ }Implementations
Sourceimpl WorkspaceModuleManagement
impl WorkspaceModuleManagement
pub fn new(root: impl Into<PathBuf>) -> Self
pub fn with_planning_context_path(self, path: impl Into<PathBuf>) -> Self
pub fn snapshot( &self, ) -> Result<ModuleManagementSnapshot, WorkspaceModuleManagementError>
pub fn preview( &self, change: ModuleRootChange, created_at: DateTime<Utc>, ) -> Result<ModuleChangePlan, WorkspaceModuleManagementError>
Sourcepub fn provider_runtime_plan(
&self,
) -> Result<ProviderRuntimePlan, WorkspaceModuleManagementError>
pub fn provider_runtime_plan( &self, ) -> Result<ProviderRuntimePlan, WorkspaceModuleManagementError>
Loads the exact reviewed workspace artifacts and compiles the sole Provider transport input. No live Provider endpoint participates in Module discovery or selection.